@@ -270,6 +270,8 @@ class Desktop(MethodsInterface):
                             "/org/xfce/SessionManager Logout False False"
         elif session == 'kde':
             logoutCommand = "/usr/bin/kquitapp ksmserver"
+        elif session == 'plasma':
+            logoutCommand = "/usr/bin/kquitapp5 ksmserver"
         elif session == 'gnome':
             logoutCommand = "/usr/bin/qdbus org.gnome.SessionManager " \
                             "/org/gnome/SessionManager Logout 1"
